@@ -1,4 +1,8 @@
-#!/usr/bin/perl
+package Mail::DKIM::Canonicalization::Base;
+use strict;
+use warnings;
+our $VERSION = '1.20200513.1'; # VERSION
+# ABSTRACT: base class for canonicalization methods
 
 # Copyright 2005-2007 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
@@ -7,87 +11,82 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use strict;
-use warnings;
-
-package Mail::DKIM::Canonicalization::Base;
-use base "Mail::DKIM::MessageParser";
+use base 'Mail::DKIM::MessageParser';
 use Carp;
 
-sub new
-{
-	my $class = shift;
-	return $class->new_object(@_);
+sub new {
+    my $class = shift;
+    return $class->new_object(@_);
 }
 
-sub init
-{
-	my $self = shift;
-	$self->SUPER::init;
+sub init {
+    my $self = shift;
+    $self->SUPER::init;
 
-	unless ($self->{output} || $self->{output_fh} || $self->{output_digest}
-		|| $self->{buffer})
-	{
-		$self->{result} = "";
-		$self->{buffer} = \$self->{result};
-	}
+    unless ( $self->{output}
+        || $self->{output_fh}
+        || $self->{output_digest}
+        || $self->{buffer} )
+    {
+        $self->{result} = '';
+        $self->{buffer} = \$self->{result};
+    }
 }
 
-sub output
-{
-	my $self = shift;
-	# my ($output) = @_;  # optimized away for speed
+sub output {
+    my $self = shift;
 
-	my $out_fh = $self->{output_fh};
-	if ($out_fh)
-	{
-		print $out_fh @_;
-	}
-	if (my $digest = $self->{output_digest})
-	{
-		$digest->add(@_);
-	}
-	if (my $out_obj = $self->{output})
-	{
-		$out_obj->PRINT(@_);
-	}
-	if (my $buffer = $self->{buffer})
-	{
-		${$self->{buffer}} .= $_[0];
-	}
+    # my ($output) = @_;  # optimized away for speed
 
-	# this supports Debug_Canonicalization
-	if (my $debug = $self->{Debug_Canonicalization})
-	{
-		if (UNIVERSAL::isa($debug, "SCALAR"))
-		{
-			$$debug .= $_[0];
-		}
-		elsif (UNIVERSAL::isa($debug, "GLOB"))
-		{
-			print $debug @_;
-		}
-		elsif (UNIVERSAL::isa($debug, "IO::Handle"))
-		{
-			$debug->print(@_);
-		}
-	}
+    my $out_fh = $self->{output_fh};
+    if ($out_fh) {
+        print $out_fh @_;
+    }
+    if ( my $digest = $self->{output_digest} ) {
+        $digest->add(@_);
+    }
+    if ( my $out_obj = $self->{output} ) {
+        $out_obj->PRINT(@_);
+    }
+    if ( my $buffer = $self->{buffer} ) {
+        ${ $self->{buffer} } .= $_[0];
+    }
+
+    # this supports Debug_Canonicalization
+    if ( my $debug = $self->{Debug_Canonicalization} ) {
+        if ( UNIVERSAL::isa( $debug, 'SCALAR' ) ) {
+            $$debug .= $_[0];
+        }
+        elsif ( UNIVERSAL::isa( $debug, 'GLOB' ) ) {
+            print $debug @_;
+        }
+        elsif ( UNIVERSAL::isa( $debug, 'IO::Handle' ) ) {
+            $debug->print(@_);
+        }
+    }
 }
 
-sub result
-{
-	my $self = shift;
-	return $self->{result};
+sub result {
+    my $self = shift;
+    return $self->{result};
 }
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Mail::DKIM::Canonicalization::Base - base class for canonicalization methods
 
+=head1 VERSION
+
+version 1.20200513.1
+
 =head1 SYNOPSIS
 
   # canonicalization results get output to STDOUT
@@ -97,7 +96,7 @@ Mail::DKIM::Canonicalization::Base - base class for canonicalization methods
 
   # add headers
   $method->add_header("Subject: this is the subject\015\012");
-  $method->finish_header;
+  $method->finish_header(Headers => \@all_headers);
 
   # add body
   $method->add_body("This is the body.\015\012");
@@ -158,6 +157,21 @@ can be accessed using the result() method.
 The body should be fed one or more "lines" at a time.
 I.e. do not feed part of a line.
 
+=head2 finish_header() - called when the header has been completely parsed
+
+  $method->finish_header(Headers => \@all_headers);
+
+Formerly the canonicalization object would only get the header data
+through successive invocations of add_header(). However, that required
+the canonicalization object to store a copy of the entire header so
+that it could choose the order in which headers were fed to the digest
+object. This is inefficient use of memory, since a message with many
+signatures may use many canonicalization objects and each
+canonicalization object has its own copy of the header.
+
+The headers array is an array of one element per header field, with
+the headers not processed/canonicalized in any way.
+
 =head2 result()
 
   my $result = $method->result;
@@ -170,13 +184,50 @@ itself, and can be accessed using this method.
 
 L<Mail::DKIM>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jason Long, E<lt>jlong@messiah.eduE<gt>
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
