@@ -1,4 +1,8 @@
-#!/usr/bin/perl
+package Mail::DKIM::Canonicalization::DkimCommon;
+use strict;
+use warnings;
+our $VERSION = '1.20200513.1'; # VERSION
+# ABSTRACT: common canonicalization
 
 # Copyright 2005-2007 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
@@ -7,10 +11,6 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use strict;
-use warnings;
-
-package Mail::DKIM::Canonicalization::DkimCommon;
 use base 'Mail::DKIM::Canonicalization::Base';
 use Carp;
 
@@ -134,9 +134,17 @@ sub body_truncated {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Mail::DKIM::Canonicalization::DkimCommon - common canonicalization methods
+Mail::DKIM::Canonicalization::DkimCommon - common canonicalization
+
+=head1 VERSION
+
+version 1.20200513.1
 
 =head1 DESCRIPTION
 
@@ -147,8 +155,61 @@ common with future canonicalization methods.
 For functionality that is common to all canonicalization methods
 (including future methods), see Mail::DKIM::Canonicalization::Base.
 
+=head1 NAME
+
+Mail::DKIM::Canonicalization::DkimCommon - common canonicalization methods
+
 =head1 SEE ALSO
 
 Mail::DKIM::Canonicalization::Base
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
+
+=head1 COPYRIGHT AND LICENSE
+
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
