@@ -1,4 +1,8 @@
-#!/usr/bin/perl
+package Mail::DKIM::DkSignature;
+use strict;
+use warnings;
+our $VERSION = '1.20200513.1'; # VERSION
+# ABSTRACT: represents a DomainKeys-Signature header
 
 # Copyright 2005-2006 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
@@ -7,38 +11,12 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use strict;
-use warnings;
-
 use Mail::DKIM::PublicKey;
 use Mail::DKIM::Algorithm::dk_rsa_sha1;
 
-package Mail::DKIM::DkSignature;
 use base 'Mail::DKIM::Signature';
 use Carp;
 
-=head1 NAME
-
-Mail::DKIM::DkSignature - represents a DomainKeys-Signature header
-
-=head1 CONSTRUCTORS
-
-=head2 new()
-
-Create a new DomainKey signature from parameters
-
-  my $signature = Mail::DKIM::DkSignature->new(
-                      [ Algorithm => 'rsa-sha1', ]
-                      [ Signature => $base64, ]
-                      [ Method => 'simple', ]
-                      [ Domain => 'example.org', ]
-                      [ Headers => 'from:subject:date:message-id', ]
-                      [ Query => 'dns', ]
-                      [ Selector => 'alpha', ]
-                      [ Key => $private_key, ]
-                  );
-
-=cut
 
 sub new {
     my $type = shift;
@@ -58,24 +36,6 @@ sub new {
     return $self;
 }
 
-=head2 parse()
-
-Create a new signature from a DomainKey-Signature header
-
-  my $sig = Mail::DKIM::DkSignature->parse(
-                  'DomainKey-Signature: a=rsa-sha1; b=yluiJ7+0=; c=nofws'
-            );
-
-Constructs a signature by parsing the provided DomainKey-Signature header
-content. You do not have to include the header name
-(i.e. "DomainKey-Signature:")
-but it is recommended, so the header name can be preserved and returned
-the same way in L</"as_string()">.
-
-Note: The input to this constructor is in the same format as the output
-of the as_string method.
-
-=cut
 
 sub parse {
     my $class = shift;
@@ -101,24 +61,7 @@ sub parse {
     return $self;
 }
 
-=head1 METHODS
 
-=cut
-
-=head2 as_string()
-
-Convert the signature header as a string.
-
-  print $signature->as_string . "\n";
-
-outputs
-
-  DomainKey-Signature: a=rsa-sha1; b=yluiJ7+0=; c=nofws
-
-As shown in the example, the as_string method can be used to generate
-the DomainKey-Signature that gets prepended to a signed message.
-
-=cut
 
 sub as_string_without_data {
     croak 'as_string_without_data not implemented';
@@ -132,14 +75,6 @@ sub body_hash {
     croak 'body_hash not implemented';
 }
 
-=head2 algorithm()
-
-Get or set the algorithm (a=) field
-
-The algorithm used to generate the signature.
-Defaults to "rsa-sha1", an RSA-signed SHA-1 digest.
-
-=cut
 
 sub algorithm {
     my $self = shift;
@@ -152,20 +87,6 @@ sub algorithm {
     return defined $a && $a ne '' ? lc $a : 'rsa-sha1';
 }
 
-=head2 canonicalization()
-
-Get or set the canonicalization (c=) field.
-
-  $signature->canonicalization('nofws');
-  $signature->canonicalization('simple');
-
-  $method = $signature->canonicalization;
-
-Message canonicalization (default is "simple"). This informs the
-verifier of the type of canonicalization used to prepare the message for
-signing.
-
-=cut
 
 sub canonicalization {
     my $self = shift;
@@ -182,17 +103,6 @@ sub DEFAULT_PREFIX {
     return 'DomainKey-Signature:';
 }
 
-=head2 domain()
-
-Get or set the domain (d=) field.
-
-  my $d = $signature->domain;          # gets the domain value
-  $signature->domain('example.org');   # sets the domain value
-
-The domain of the signing entity, as specified in the signature.
-This is the domain that will be queried for the public key.
-
-=cut
 
 sub domain {
     my $self = shift;
@@ -264,39 +174,10 @@ sub hash_algorithm {
     return $algorithm eq 'rsa-sha1' ? 'sha1' : undef;
 }
 
-=head2 headerlist()
-
-Get or set the signed header fields (h=) field.
-
-  $signature->headerlist('a:b:c');
-
-  my $headerlist = $signature->headerlist;
-
-  my @headers = $signature->headerlist;
-
-Signed header fields. A colon-separated list of header field names
-that identify the header fields presented to the signing algorithm.
-
-In scalar context, the list of header field names will be returned
-as a single string, with the names joined together with colons.
-In list context, the header field names will be returned as a list.
-
-=cut
 
 #sub headerlist
 # is in Signature.pm
 
-=head2 identity()
-
-Get the signing identity.
-
-  my $i = $signature->identity;
-
-In DomainKey signatures, the signing identity is the first address
-found in the Sender header or the From header. This field is
-populated by the L<Verifier|Mail::DKIM::Verifier> when processing a DomainKey signature.
-
-=cut
 
 sub identity {
     my $self = shift;
@@ -304,17 +185,6 @@ sub identity {
     return $self->{dk_identity};
 }
 
-=head2 identity_source()
-
-Determine which header had the identity.
-
-  my $source = $signature->identity_source;
-
-If the message is being verified, this method will tell you which
-of the message headers was used to determine the signature identity.
-Possible values are "header.sender" and "header.from".
-
-=cut
 
 sub identity_source {
     my $self = shift;
@@ -341,14 +211,6 @@ sub method {
     croak 'method not implemented (use canonicalization instead)';
 }
 
-=head2 protocol()
-
-Get or set the query methods (q=) field.
-
-A colon-separated list of query methods used to retrieve the public
-key (default is "dns").
-
-=cut
 
 sub protocol {
     my $self = shift;
@@ -358,27 +220,12 @@ sub protocol {
 
     # although draft-delany-domainkeys-base-06 does mandate presence of a
     # q=dns tag, it is quote common that q tag is missing - be merciful
-    return !defined( $self->get_tag('q') ) ? 'dns' : $self->get_tag('q');
+    return !defined( $self->get_tag('q') ) ? 'dns' : lc $self->get_tag('q');
 }
 
-=head2 selector()
-
-Get or set the selector (s=) field.
-
-The selector subdivides the namespace for the "d=" (domain) tag.
-
-=cut
 
 # same as parent class
 
-=head2 signature()
-
-Get or set the signature data (b=) field.
-
-The signature data. Whitespace is automatically stripped from the
-returned value.
-
-=cut
 
 # same as parent class
 
@@ -390,22 +237,210 @@ sub version {
     croak 'version not implemented';
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::DKIM::DkSignature - represents a DomainKeys-Signature header
+
+=head1 VERSION
+
+version 1.20200513.1
+
+=head1 CONSTRUCTORS
+
+=head2 new()
+
+Create a new DomainKey signature from parameters
+
+  my $signature = Mail::DKIM::DkSignature->new(
+                      [ Algorithm => 'rsa-sha1', ]
+                      [ Signature => $base64, ]
+                      [ Method => 'simple', ]
+                      [ Domain => 'example.org', ]
+                      [ Headers => 'from:subject:date:message-id', ]
+                      [ Query => 'dns', ]
+                      [ Selector => 'alpha', ]
+                      [ Key => $private_key, ]
+                  );
+
+=head2 parse()
+
+Create a new signature from a DomainKey-Signature header
+
+  my $sig = Mail::DKIM::DkSignature->parse(
+                  'DomainKey-Signature: a=rsa-sha1; b=yluiJ7+0=; c=nofws'
+            );
+
+Constructs a signature by parsing the provided DomainKey-Signature header
+content. You do not have to include the header name
+(i.e. "DomainKey-Signature:")
+but it is recommended, so the header name can be preserved and returned
+the same way in L</"as_string()">.
+
+Note: The input to this constructor is in the same format as the output
+of the as_string method.
+
+=head1 METHODS
+
+=head2 as_string()
+
+Convert the signature header as a string.
+
+  print $signature->as_string . "\n";
+
+outputs
+
+  DomainKey-Signature: a=rsa-sha1; b=yluiJ7+0=; c=nofws
+
+As shown in the example, the as_string method can be used to generate
+the DomainKey-Signature that gets prepended to a signed message.
+
+=head2 algorithm()
+
+Get or set the algorithm (a=) field
+
+The algorithm used to generate the signature.
+Defaults to "rsa-sha1", an RSA-signed SHA-1 digest.
+
+=head2 canonicalization()
+
+Get or set the canonicalization (c=) field.
+
+  $signature->canonicalization('nofws');
+  $signature->canonicalization('simple');
+
+  $method = $signature->canonicalization;
+
+Message canonicalization (default is "simple"). This informs the
+verifier of the type of canonicalization used to prepare the message for
+signing.
+
+=head2 domain()
+
+Get or set the domain (d=) field.
+
+  my $d = $signature->domain;          # gets the domain value
+  $signature->domain('example.org');   # sets the domain value
+
+The domain of the signing entity, as specified in the signature.
+This is the domain that will be queried for the public key.
+
+=head2 headerlist()
+
+Get or set the signed header fields (h=) field.
+
+  $signature->headerlist('a:b:c');
+
+  my $headerlist = $signature->headerlist;
+
+  my @headers = $signature->headerlist;
+
+Signed header fields. A colon-separated list of header field names
+that identify the header fields presented to the signing algorithm.
+
+In scalar context, the list of header field names will be returned
+as a single string, with the names joined together with colons.
+In list context, the header field names will be returned as a list.
+
+=head2 identity()
+
+Get the signing identity.
+
+  my $i = $signature->identity;
+
+In DomainKey signatures, the signing identity is the first address
+found in the Sender header or the From header. This field is
+populated by the L<Verifier|Mail::DKIM::Verifier> when processing a DomainKey signature.
+
+=head2 identity_source()
+
+Determine which header had the identity.
+
+  my $source = $signature->identity_source;
+
+If the message is being verified, this method will tell you which
+of the message headers was used to determine the signature identity.
+Possible values are "header.sender" and "header.from".
+
+=head2 protocol()
+
+Get or set the query methods (q=) field.
+
+A colon-separated list of query methods used to retrieve the public
+key (default is "dns").
+
+=head2 selector()
+
+Get or set the selector (s=) field.
+
+The selector subdivides the namespace for the "d=" (domain) tag.
+
+=head2 signature()
+
+Get or set the signature data (b=) field.
+
+The signature data. Whitespace is automatically stripped from the
+returned value.
+
 =head1 SEE ALSO
 
 L<Mail::DKIM::Signature> for DKIM-Signature headers
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jason Long, E<lt>jlong@messiah.eduE<gt>
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007,2010 by Messiah College
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
-
-1;
