@@ -1,4 +1,8 @@
-#!/usr/bin/perl
+package Mail::DKIM::DkimPolicy;
+use strict;
+use warnings;
+our $VERSION = '1.20200513.1'; # VERSION
+# ABSTRACT: represents a DKIM Sender Signing Practices record
 
 # Copyright 2005-2007 Messiah College.
 # Jason Long <jlong@messiah.edu>
@@ -7,49 +11,12 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use strict;
-use warnings;
-
-package Mail::DKIM::DkimPolicy;
 use base 'Mail::DKIM::Policy';
 
 # base class is used for parse(), as_string()
 
 use Mail::DKIM::DNS;
 
-=head1 NAME
-
-Mail::DKIM::DkimPolicy - represents a DKIM Sender Signing Practices record
-
-=head1 DESCRIPTION
-
-The Sender Signing Practices (SSP) record can be published by any
-domain to help a receiver know what to do when it encounters an unsigned
-message claiming to originate from that domain.
-
-The record is published as a DNS TXT record at _policy._domainkey.DOMAIN
-where DOMAIN is the domain of the message's "From" address.
-
-This record format has been superceded by ADSP. See
-L<Mail::DKIM::AuthorDomainPolicy> for information about ADSP.
-It is implemented here because at one time it appeared this is what
-would be standardized by the IETF. It will be removed from Mail::DKIM
-at some point in the future.
-The last version of the SSP specification can be found at
-L<http://tools.ietf.org/html/draft-ietf-dkim-ssp-02>.
-
-=head1 CONSTRUCTORS
-
-=head2 fetch()
-
-Lookup a DKIM signing practices record.
-
-  my $policy = Mail::DKIM::DkimPolicy->fetch(
-            Protocol => 'dns',
-            Author => 'jsmith@example.org',
-          );
-
-=cut
 
 # get_lookup_name() - determine name of record to fetch
 #
@@ -71,13 +38,6 @@ sub get_lookup_name {
     return '_policy._domainkey.' . $prms->{Domain};
 }
 
-=head2 new()
-
-Construct a default policy object.
-
-  my $policy = Mail::DKIM::DkimPolicy->new;
-
-=cut
 
 sub new {
     my $class = shift;
@@ -93,38 +53,6 @@ sub default {
     return $DEFAULT_POLICY;
 }
 
-=head1 METHODS
-
-=head2 apply()
-
-Apply the policy to the results of a DKIM verifier.
-
-  my $result = $policy->apply($dkim_verifier);
-
-The caller must provide an instance of L<Mail::DKIM::Verifier>, one which
-has already been fed the message being verified.
-
-Possible results are:
-
-=over
-
-=item accept
-
-The message is approved by the sender signing policy.
-
-=item reject
-
-The message is rejected by the sender signing policy.
-It can be considered very suspicious.
-
-=item neutral
-
-The message is neither approved nor rejected by the sender signing
-policy. It can be considered somewhat suspicious.
-
-=back
-
-=cut
 
 sub apply {
     my $self = shift;
@@ -167,6 +95,171 @@ sub apply {
     return 'neutral';
 }
 
+
+sub flags {
+    my $self = shift;
+
+    (@_)
+      and $self->{tags}->{t} = shift;
+
+    $self->{tags}->{t};
+}
+
+
+sub is_implied_default_policy {
+    my $self           = shift;
+    my $default_policy = ref($self)->default;
+    return ( $self == $default_policy );
+}
+
+
+sub location {
+    my $self = shift;
+    return $self->{Domain};
+}
+
+sub name {
+    return 'author';
+}
+
+
+sub policy {
+    my $self = shift;
+
+    (@_)
+      and $self->{tags}->{dkim} = shift;
+
+    if ( defined $self->{tags}->{dkim} ) {
+        return $self->{tags}->{dkim};
+    }
+    elsif ( defined $self->{tags}->{o} ) {
+        return $self->{tags}->{o};
+    }
+    else {
+        return 'unknown';
+    }
+}
+
+
+sub signall {
+    my $self = shift;
+
+    return $self->policy
+      && ( $self->policy =~ /all/i
+        || $self->policy eq '-' );    # an older symbol for "all"
+}
+
+
+sub signall_strict {
+    my $self = shift;
+
+    return $self->policy
+      && ( $self->policy =~ /strict/i
+        || $self->policy eq '!' );    # "!" is an older symbol for "strict"
+}
+
+sub signsome {
+    my $self = shift;
+
+    $self->policy
+      or return 1;
+
+    $self->policy eq '~'
+      and return 1;
+
+    return;
+}
+
+
+sub testing {
+    my $self = shift;
+    my $t    = $self->flags;
+    ( $t && $t =~ /y/i )
+      and return 1;
+    return;
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::DKIM::DkimPolicy - represents a DKIM Sender Signing Practices record
+
+=head1 VERSION
+
+version 1.20200513.1
+
+=head1 DESCRIPTION
+
+The Sender Signing Practices (SSP) record can be published by any
+domain to help a receiver know what to do when it encounters an unsigned
+message claiming to originate from that domain.
+
+The record is published as a DNS TXT record at _policy._domainkey.DOMAIN
+where DOMAIN is the domain of the message's "From" address.
+
+This record format has been superceded by ADSP. See
+L<Mail::DKIM::AuthorDomainPolicy> for information about ADSP.
+It is implemented here because at one time it appeared this is what
+would be standardized by the IETF. It will be removed from Mail::DKIM
+at some point in the future.
+The last version of the SSP specification can be found at
+L<http://tools.ietf.org/html/draft-ietf-dkim-ssp-02>.
+
+=head1 CONSTRUCTORS
+
+=head2 fetch()
+
+Lookup a DKIM signing practices record.
+
+  my $policy = Mail::DKIM::DkimPolicy->fetch(
+            Protocol => 'dns',
+            Author => 'jsmith@example.org',
+          );
+
+=head2 new()
+
+Construct a default policy object.
+
+  my $policy = Mail::DKIM::DkimPolicy->new;
+
+=head1 METHODS
+
+=head2 apply()
+
+Apply the policy to the results of a DKIM verifier.
+
+  my $result = $policy->apply($dkim_verifier);
+
+The caller must provide an instance of L<Mail::DKIM::Verifier>, one which
+has already been fed the message being verified.
+
+Possible results are:
+
+=over
+
+=item accept
+
+The message is approved by the sender signing policy.
+
+=item reject
+
+The message is rejected by the sender signing policy.
+It can be considered very suspicious.
+
+=item neutral
+
+The message is neither approved nor rejected by the sender signing
+policy. It can be considered somewhat suspicious.
+
+=back
+
 =head2 flags()
 
 Get or set the flags (t=) tag.
@@ -187,17 +280,6 @@ not to subdomains.
 
 =back
 
-=cut
-
-sub flags {
-    my $self = shift;
-
-    (@_)
-      and $self->{tags}->{t} = shift;
-
-    $self->{tags}->{t};
-}
-
 =head2 is_implied_default_policy()
 
 Is this policy implied?
@@ -208,14 +290,6 @@ If you fetch the policy for a particular domain, but that domain
 does not have a policy published, then the "default policy" is
 in effect. Use this method to detect when that happens.
 
-=cut
-
-sub is_implied_default_policy {
-    my $self           = shift;
-    my $default_policy = ref($self)->default;
-    return ( $self == $default_policy );
-}
-
 =head2 location()
 
 Where the policy was fetched from.
@@ -228,17 +302,6 @@ If the policy is user-specific, TBD.
 If nothing is published for the domain, and the default policy
 was returned instead, the location will be C<undef>.
 
-=cut
-
-sub location {
-    my $self = shift;
-    return $self->{Domain};
-}
-
-sub name {
-    return 'author';
-}
-
 =head2 policy()
 
 Get or set the outbound signing policy (dkim=) tag.
@@ -266,65 +329,14 @@ All mail from the entity is signed with Originator signatures.
 
 =back
 
-=cut
-
-sub policy {
-    my $self = shift;
-
-    (@_)
-      and $self->{tags}->{dkim} = shift;
-
-    if ( defined $self->{tags}->{dkim} ) {
-        return $self->{tags}->{dkim};
-    }
-    elsif ( defined $self->{tags}->{o} ) {
-        return $self->{tags}->{o};
-    }
-    else {
-        return 'unknown';
-    }
-}
-
 =head2 signall()
 
 True if policy is "all".
 
-=cut
-
-sub signall {
-    my $self = shift;
-
-    return $self->policy
-      && ( $self->policy =~ /all/i
-        || $self->policy eq '-' );    # an older symbol for "all"
-}
-
 =head2 signall_strict()
 
 True if policy is "strict".
 
-=cut
-
-sub signall_strict {
-    my $self = shift;
-
-    return $self->policy
-      && ( $self->policy =~ /strict/i
-        || $self->policy eq '!' );    # "!" is an older symbol for "strict"
-}
-
-sub signsome {
-    my $self = shift;
-
-    $self->policy
-      or return 1;
-
-    $self->policy eq '~'
-      and return 1;
-
-    return;
-}
-
 =head2 testing()
 
 Checks the testing flag.
@@ -334,18 +346,6 @@ Checks the testing flag.
 If nonzero, the testing flag is set on the signing policy, and the
 verify should not consider a message suspicious based on this policy.
 
-=cut
-
-sub testing {
-    my $self = shift;
-    my $t    = $self->flags;
-    ( $t && $t =~ /y/i )
-      and return 1;
-    return;
-}
-
-1;
-
 =head1 BUGS
 
 =over
@@ -358,13 +358,50 @@ section 4 of the dkim-ssp Internet Draft.
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jason Long, E<lt>jlong@messiah.eduE<gt>
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
