@@ -1,15 +1,15 @@
-#!/usr/bin/perl
-#
+package Mail::DKIM::Key;
+use strict;
+use warnings;
+# ABSTRACT: Represents a DKIM Key
+our $VERSION = '1.20200513.1'; # VERSION
+
 # Copyright 2006 Jason Long. All rights reserved.
 #
 # Copyright (c) 2004 Anthony D. Urso. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-package Mail::DKIM::Key;
-
-use strict;
-
 sub cork {
     my $self = shift;
 
@@ -88,3 +88,68 @@ sub calculate_EM {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::DKIM::Key - Represents a DKIM Key
+
+=head1 VERSION
+
+version 1.20200513.1
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
+
+=head1 COPYRIGHT AND LICENSE
+
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
