@@ -1,4 +1,8 @@
-#!/usr/bin/perl
+package Mail::DKIM::PrivateKey;
+use strict;
+use warnings;
+our $VERSION = '1.20200513.1'; # VERSION
+# ABSTRACT: a private key loaded in memory for DKIM signing
 
 # Copyright 2005-2007 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
@@ -7,53 +11,11 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use strict;
-use warnings;
 
-=head1 NAME
-
-Mail::DKIM::PrivateKey - a private key loaded in memory for DKIM signing
-
-=head1 SYNOPSIS
-
- my $key1 = Mail::DKIM::PrivateKey->load(
-               File => '/path/to/private.key');
-
- my $key2 = Mail::DKIM::PrivateKey->load(
-               Data => $base64);
-
- # use the loaded key in a DKIM signing object
- my $dkim = Mail::DKIM::Signer->new(
-               Key => $key2,
-             );
-
-=cut
-
-package Mail::DKIM::PrivateKey;
 use base 'Mail::DKIM::Key';
 use Carp;
 *calculate_EM = \&Mail::DKIM::Key::calculate_EM;
 
-=head1 CONSTRUCTOR
-
-=head2 load() - loads a private key into memory
-
- my $key1 = Mail::DKIM::PrivateKey->load(
-               File => '/path/to/private.key');
-
-Loads the Base64-encoded key from the specified file.
-
-  my $key2 = Mail::DKIM::PrivateKey->load(Data => $base64);
-
-Loads the Base64-encoded key from a string already in memory.
-
-  my $key3 = Mail::DKIM::PrivateKey->load(Cork => $openssl_object);
-
-Creates a Mail::DKIM::PrivateKey wrapper object for the given
-OpenSSL key object. The key object should be of type
-L<Crypt::OpenSSL::RSA>.
-
-=cut
 
 sub load {
     my $class = shift;
@@ -88,15 +50,6 @@ sub load {
     return $self;
 }
 
-=head1 METHODS
-
-=head2 cork() - access the underlying OpenSSL key object
-
-  $openssl_object = $key->cork;
-
-The returned object is of type L<Crypt::OpenSSL::RSA>.
-
-=cut
 
 sub convert {
     use Crypt::OpenSSL::RSA;
@@ -118,7 +71,10 @@ sub convert {
 
     my $cork;
 
-    eval { $cork = new_private_key Crypt::OpenSSL::RSA($pkcs); };
+    eval {
+        local $SIG{__DIE__};
+        $cork = new_private_key Crypt::OpenSSL::RSA($pkcs);
+    };
 
     $@
       and $self->errorstr($@),
@@ -151,19 +107,6 @@ sub sign_sha1_digest {
     return $self->sign_digest( 'SHA-1', $digest );
 }
 
-=head2 sign_digest()
-
-Cryptographically sign the given message digest.
-
-  $key->sign_digest('SHA-1', sha1('my message text'));
-
-The first parameter is the name of the digest: one of "SHA-1", "SHA-256".
-
-The second parameter is the message digest as a binary string.
-
-The result should be the signed digest as a binary string.
-
-=cut
 
 sub sign_digest {
     my $self = shift;
@@ -177,18 +120,121 @@ sub sign_digest {
     return $rsa_priv->decrypt($EM);
 }
 
-=head1 AUTHOR
+__END__
 
-Jason Long, E<lt>jlong@messiah.eduE<gt>
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::DKIM::PrivateKey - a private key loaded in memory for DKIM signing
+
+=head1 VERSION
+
+version 1.20200513.1
+
+=head1 SYNOPSIS
+
+ my $key1 = Mail::DKIM::PrivateKey->load(
+               File => '/path/to/private.key');
+
+ my $key2 = Mail::DKIM::PrivateKey->load(
+               Data => $base64);
+
+ # use the loaded key in a DKIM signing object
+ my $dkim = Mail::DKIM::Signer->new(
+               Key => $key2,
+             );
+
+=head1 CONSTRUCTOR
+
+=head2 load() - loads a private key into memory
+
+ my $key1 = Mail::DKIM::PrivateKey->load(
+               File => '/path/to/private.key');
+
+Loads the Base64-encoded key from the specified file.
+
+  my $key2 = Mail::DKIM::PrivateKey->load(Data => $base64);
+
+Loads the Base64-encoded key from a string already in memory.
+
+  my $key3 = Mail::DKIM::PrivateKey->load(Cork => $openssl_object);
+
+Creates a Mail::DKIM::PrivateKey wrapper object for the given
+OpenSSL key object. The key object should be of type
+L<Crypt::OpenSSL::RSA>.
+
+=head1 METHODS
+
+=head2 cork() - access the underlying OpenSSL key object
+
+  $openssl_object = $key->cork;
+
+The returned object is of type L<Crypt::OpenSSL::RSA>.
+
+=head2 sign_digest()
+
+Cryptographically sign the given message digest.
+
+  $key->sign_digest('SHA-1', sha1('my message text'));
+
+The first parameter is the name of the digest: one of "SHA-1", "SHA-256".
+
+The second parameter is the message digest as a binary string.
+
+The result should be the signed digest as a binary string.
+
+1;
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2008 by Messiah College
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
-
-1;
